##  Step 2: Select a Jira Project
After establishing the connection, choose the Jira project you want to integrate with.
To select a project, do the following:
  1. Go to the Project Mapping tab and select Add Projects.
  2. Under Type Matching, select the Jira project you want to integrate.
  3. Choose the corresponding fact sheet type in SAP LeanIX.
For example, Initiative.


![Screen capture of project mapping settings for the Jira integration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiocb688fdd1ff14ce3b35d678fd6272f24_LowRes.png)
Overview of Project Mapping Options
